/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import PropTypes from 'prop-types';
import React, {useEffect, useState} from 'react';

import ActiveFiltersBar from './components/ActiveFiltersBar';
import BulkActions from './components/BulkActions';
import NavBar from './components/NavBar';
import FiltersContext from './components/filters/FiltersContext';

function ManagementBar({
	bulkActions,
	creationMenu,
	filters: propFilters,
	fluid,
	onFiltersChange,
	selectAllItems,
	selectedItemsKey,
	selectedItemsValue,
	selectionType,
	showSearch,
	total,
}) {
	const [filters, setFilters] = useState(propFilters);

	useEffect(() => {
		onFiltersChange(filters);
	}, [filters, onFiltersChange]);

	const state = {
		filters,
		resetFiltersValue: () => {
			setFilters((filters) => {
				return filters.map((element) => ({
					...element,
					additionalData: undefined,
					odataFilterString: undefined,
					resumeCustomLabel: undefined,
					value: undefined,
				}));
			});
		},
		updateFilterState: (id, value, formattedValue, odataFilterString) => {
			setFilters((filters) => {
				return filters.map((filter) => ({
					...filter,
					...(filter.id === id
						? {
								formattedValue,
								odataFilterString,
								value,
						  }
						: {}),
				}));
			});
		},
	};

	return (
		<FiltersContext.Provider value={state}>
			{selectionType === 'multiple' && (
				<BulkActions
					bulkActions={bulkActions}
					fluid={fluid}
					selectAllItems={selectAllItems}
					selectedItemsKey={selectedItemsKey}
					selectedItemsValue={selectedItemsValue}
					total={total}
				/>
			)}

			{(!selectedItemsValue.length || selectionType === 'single') && (
				<NavBar creationMenu={creationMenu} showSearch={showSearch} />
			)}

			<ActiveFiltersBar disabled={!!selectedItemsValue.length} />
		</FiltersContext.Provider>
	);
}

ManagementBar.propTypes = {
	bulkActions: PropTypes.arrayOf(
		PropTypes.shape({
			href: PropTypes.string.isRequired,
			icon: PropTypes.string.isRequired,
			label: PropTypes.string.isRequired,
			method: PropTypes.string,
			target: PropTypes.oneOf(['sidePanel', 'modal']),
		})
	),
	creationMenu: PropTypes.shape({
		primaryItems: PropTypes.array,
		secondaryItems: PropTypes.array,
	}),
	filters: PropTypes.array,
	fluid: PropTypes.bool,
	onFiltersChange: PropTypes.func.isRequired,
	selectedItemsKey: PropTypes.string,
	selectedItemsValue: PropTypes.array,
	selectionType: PropTypes.oneOf(['single', 'multiple']).isRequired,
	showSearch: PropTypes.bool,
	total: PropTypes.number,
};

ManagementBar.defaultProps = {
	filters: [],
	fluid: false,
	showSearch: true,
};

export default ManagementBar;
