/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

import {OPEN_MODAL, OPEN_MODAL_FROM_IFRAME} from './eventsDefinitions';
import {logError} from './logError';

export function isPageInIframe() {
	return window.location !== window.parent.location;
}

const registeredModals = new Set();
let modalsCounter = 0;

if (!isPageInIframe()) {
	Liferay.on(OPEN_MODAL_FROM_IFRAME, (payload) => {
		if (!registeredModals.size) {
			return logError('No registered modals found.');
		}

		const modalsArray = Array.from(registeredModals);
		const lastRegisteredModal = modalsArray[modalsArray.length - 1];

		Liferay.fire(OPEN_MODAL, {
			...payload,
			id: lastRegisteredModal,
		});
	});
}

Liferay.on('beforeNavigate', () => {
	registeredModals.clear();
});

export function subscribeModal() {
	registeredModals.add(++modalsCounter);

	return modalsCounter;
}

export function unsubscribeModal(id) {
	registeredModals.delete(id);
}
